/* eslint-disable import/no-extraneous-dependencies */
/* eslint-disable global-require */

const { argv } = require('yargs');
const testingServer = require('./test/client/app');

if (!process.env.TRAVIS) {
  process.env.CHROME_BIN = require('puppeteer').executablePath();
}

module.exports = function karmaConfig(config) {
  const localConfig = {
    frameworks: [
      'browserify',
      'mocha',
      'chai',
      'expressServer'
    ],

    port: 5000,

    files: [
      'test/client/**/*.js',
      {
        pattern: 'test/resources/**/*.*',
        watched: false,
        included: false,
        served: true,
        nocache: false
      },
      {
        pattern: 'authentication/**/*.*',
        watched: false,
        included: false,
        served: true,
        nocache: false
      }
    ],

    preprocessors: {
      'test/client/**/*.js': ['browserify']
    },

    proxies: {
      '/resources/': 'http://localhost:5000/base/test/resources/'
    },

    browserify: {
      debug: true,
      transform: ['brfs']
    },

    browserNoActivityTimeout: 240000,

    captureTimeout: 240000,

    logLevel: config.LOG_INFO,

    // just run once by default unless --watch flag is passed
    singleRun: !argv.watch,

    browsers: process.env.TRAVIS ? ['Chrome_travis_ci'] : ['ChromeHeadless'],

    customLaunchers: {
      Chrome_travis_ci: {
        base: 'Chrome',
        flags: ['--no-sandbox']
      }
    },

    expressServer: {
      serverPort: 5001,
      accessControlAllowOrigin: '*',
      accessControlAllowHeaders: [
        'x-requested-with',
        'Content-Type',
        'Content-Length',
        'Content-Range',
        'Content-Encoding',
        'Pragma',
        'Cache-Control',
        'Authorization'
      ].join(', '),
      extensions: [testingServer]
    },

    // Tell karma all the plugins we're going to be using to prevent warnings
    plugins: [
      'karma-browserify',
      'karma-chai',
      'karma-mocha',
      'karma-express-server',

      // launchers
      'karma-chrome-launcher',

      // preprocessors
      'karma-sourcemap-loader'
    ]
  };

  config.set(localConfig);
};
