'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/**
 * Keep track of open popup windows so we only have one open at a time.
 *
 * @type {Object}
 */
var openPopup = void 0;
var openModal = void 0;
var closeInterval = void 0;

/**
 * Closes previously opened windows and modals.
 */
function closeAll() {
  if (openPopup) {
    openPopup.close();
  }
  if (openModal) {
    openModal.close();
  }

  openPopup = null;
  openModal = null;

  window.clearInterval(closeInterval);
}

/**
 * Pop open an authentication window. It adds some additional safe guards such
 * as catching blocked popup windows, listening for window closes, simplified
 * window positioning, etc.
 *
 * @return {Object} Execute `close` when the window is safe to cleared.
 */
module.exports = function (url, cb) {
  var width = Math.min(720, window.screen.availWidth);
  var height = Math.min(480, window.screen.availHeight);
  var top = Math.min(100, (window.screen.availHeight - height) / 2);
  var left = (window.screen.availWidth - width) / 2;

  function done(err) {
    closeAll();

    cb(err);
  }

  // Close previously open popup windows and modals.
  closeAll();

  // Open a popup window when the authentication button is pressed.
  openPopup = window.open(url, '', ['top=' + top, 'left=' + left, 'width=' + width, 'height=' + height, 'scrollbars=1'].join(','));

  if ((typeof openPopup === 'undefined' ? 'undefined' : _typeof(openPopup)) !== 'object') {
    openPopup = null;
    done(new Error('Popup window blocked'));
  }

  // Catch window closes before authentication is complete.
  closeInterval = window.setInterval(function () {
    if (openPopup.closed) {
      openPopup = null;
      done(new Error('Popup window closed'));
    }
  }, 400);

  return {
    close: function close() {
      // Remove any references to open modals and windows.
      return closeAll();
    }
  };
};
//# sourceMappingURL=authWindow.js.map