'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var request = require('./ajax');

var isBrowser = !!process.browser;

module.exports = {
  resolveClient: resolveClient
};

function resolveClient(_ref) {
  var url = _ref.url,
      groupId = _ref.groupId,
      assetId = _ref.assetId,
      version = _ref.version,
      options = _ref.options;

  if (isBrowser) {
    if (typeof url !== 'string' && (typeof url === 'undefined' ? 'undefined' : _typeof(url)) !== 'object' && (!groupId || !assetId || !version)) {
      return Promise.reject(new Error('Provide a source or a GAV for the RAML document'));
    }

    return new Promise(function (resolve, reject) {
      if ((typeof url === 'undefined' ? 'undefined' : _typeof(url)) === 'object') {
        resolve(url);
        return;
      }

      var headers = {
        Accept: 'application/json'
      };

      if (options.authorization) {
        headers.Authorization = options.authorization;
      }

      if (!url) {
        url = options.ramlQueryBuilder({ groupId: groupId, assetId: assetId, version: version });
      }

      request({ url: url, headers: headers }, function (err, xhr) {
        if (err) {
          reject(err);
          return;
        }

        try {
          if (xhr.statusCode >= 300 && xhr.statusCode < 400) {
            throw new Error('Redirect is not supported');
          } else if (xhr.statusCode >= 400) {
            throw new Error('Request has failed');
          }

          resolve(JSON.parse(xhr.body));
        } catch (innerErr) {
          reject(innerErr);
        }
      });
    });
  }

  if (typeof url !== 'string' && (typeof url === 'undefined' ? 'undefined' : _typeof(url)) !== 'object') {
    return Promise.reject(new Error('Provide a source for the RAML document'));
  }

  return Promise.resolve(url);
}
//# sourceMappingURL=client.js.map