const { expect } = require('chai');
const fs = require('fs');
const ramlClient = require('../../../src');

describe('Exchange Auth RAML', () => {
  let client;
  let API;
  let editor;

  before(() => {
    editor = {};

    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      authorization: 'my token',
      xhr: XMLHttpRequest,
      editor: {
        languages: {
          typescript: {
            javascriptDefaults: {
              addExtraLib: (content, file) => {
                editor[file] = content;
              },
              getExtraLibs: () => ({})
            }
          }
        }
      },
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(function createClient() {
    this.timeout(10000);

    return API.createClient('exchange', 'exchange', 'api.v1.raml', '1.0.0')
      .then((result) => {
        client = result;
      });
  });

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.exchange).to.exist;
  });

  it('matches files', () => {
    /* eslint-disable */
    const clientContent = fs.readFileSync(__dirname + '/exchange-client.d.ts', 'utf8');
    const api = fs.readFileSync(__dirname + '/api.d.ts', 'utf8');
    const apiResponse = fs.readFileSync(__dirname + '/api-response.d.ts', 'utf8');
    /* eslint-enable */

    expect(editor['exchange-client.d.ts'].trim()).to.be.eql(clientContent.trim());
    expect(editor['api-response.d.ts'].trim()).to.be.eql(apiResponse.trim());
    expect(editor['api.d.ts'].trim()).to.be.eql(api.trim());
  });
});
