const { expect } = require('chai');
const ramlClient = require('../../../src');

describe('OAuth2 code RAML', () => {
  let client;
  let API;

  before(() => {
    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      authorization: 'my token',
      xhr: XMLHttpRequest,
      sync: true,
      editor: {
        languages: {
          typescript: {
            javascriptDefaults: {
              addExtraLib: () => {
                // console.log(content);
              },
              getExtraLibs: () => ({})
            }
          }
        }
      },
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(() => (
    API.createClient('oauth2Code', 'oauth2-code', 'api.raml', '1.0.0', { baseUri: 'http://localhost:5001' })
      .then((result) => {
        client = result;
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.oauth2Code).to.exist;
  });

  it('does an unauthorized api call', () => {
    expect(client.content.get({ search: 'my search' }).body.results).to.eql(['my search']);
  });

  context('authorized', () => {
    before(() => API.authenticate(client, { clientId: 'client', clientSecret: 'secret', scopes: ['user'] }));

    it('has the token assigned', () => {
      const accessTokenResponse = {
        code: 'foo',
        grant_type: 'authorization_code',
        redirect_uri: 'http://localhost:5000/resources/oauth.html',
        client_id: 'client',
        client_secret: 'secret'
      };

      expect(client['!client'].authentication['OAuth 2.0'].clientId).to.be.eql('client');
      expect(client['!client'].authentication['OAuth 2.0'].accessToken).to.be.eql('my-token');
      expect(client['!client'].authentication['OAuth 2.0'].tokenType).to.be.eql('bearer');
      expect(client['!client'].authentication['OAuth 2.0'].response.body).to.be.eql(accessTokenResponse);
    });

    it('does an authorized api call', () => {
      expect(client.authorized.get().body.header).to.eql('Bearer my-token');
    });
  });
});
