const { expect } = require('chai');
const ramlClient = require('../../../src');
const ramlParser = require('raml-1-parser');

describe('OAuth2 token RAML', () => {
  let client;
  let API;
  let raml;

  before(() => {
    API = ramlClient({
      redirectUri: 'http://localhost:5000/resources/oauth.html',
      proxy: 'http://localhost:5001/myproxy/',
      prompt: () => Promise.resolve({
        clientId: 'client',
        scopes: ['user']
      }),
      authorization: 'my token',
      sync: true,
      xhr: XMLHttpRequest,
      ramlQueryBuilder: ({ groupId, assetId, version }) => `http://localhost:5001/assets/${groupId}/${assetId}/${version}/api/json`
    });
  });

  before(() => (
    ramlParser
      .loadApi('http://localhost:5000/base/test/resources/oauth2-token/api.raml', {
        attributeDefaults: true,
        rejectOnErrors: false
      })
      .then((api) => {
        api = api.expand ? api.expand(true) : api;

        const jsonOptions = {
          serializeMetadata: false,
          dumpSchemaContents: false,
          rootNodeDetails: false
        };

        return api.toJSON(jsonOptions);
      })
      .then((api) => {
        raml = api;
      })
  ));

  before(() => (
    API.createClient(raml)
      .then((result) => {
        client = result;
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
    expect(global.oauth2Token).to.not.exist;
  });

  it('does an api call', () => {
    expect(client.content.get({ search: 'my search' }).body.results).to.eql(['my search']);
  });

  context('authorized', () => {
    before(() => API.authenticate(client));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['OAuth 2.0'].accessToken).to.be.eql('token');
    });

    it('does an authorized api call', () => {
      expect(client.authorized.get().body.header).to.eql('Bearer token');
    });
  });
});
