const { expect } = require('chai');
const path = require('path');
const ramlClient = require('../../../src');
const ramlParser = require('raml-1-parser');

describe('Basic Auth RAML', () => {
  let client;
  let API;
  let raml;

  before(() => {
    API = ramlClient();
  });

  before(() => (
    ramlParser
      .loadApi(path.join(process.cwd(), 'test/resources/basic/api.raml'))
      .then(api => api.toJSON())
      .then((api) => {
        raml = api;
      })
  ));

  before(() => (
    API.createClient(raml)
      .then((result) => {
        client = result;
      })
  ));

  it('creates the client', () => {
    expect(client).to.exist;
  });

  it('does an unauthorized api call', () => client.content.get({ search: 'my search' })
    .then((response) => {
      expect(response.body.data).to.eql(['my search']);
    }));

  context('authorized', () => {
    before(() => API.authenticate(client, { username: 'username', password: 'password' }));

    it('has the token assigned', () => {
      expect(client['!client'].authentication['Basic Authentication'].username).to.be.eql('username');
      expect(client['!client'].authentication['Basic Authentication'].password).to.be.eql('password');
    });

    it('does an authorized api call', () => client.authorized.get()
      .then((response) => {
        expect(response.body.header).to.eql('Basic dXNlcm5hbWU6cGFzc3dvcmQ=');
      }));
  });
});
